durtools.positive_integer_to_implied_prolation_multipler
========================================================

.. autofunction:: abjad.tools.durtools.positive_integer_to_implied_prolation_multipler
